package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.RmsMaterialSteelServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/22 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmsmaterialsteel")
public class RmsMaterialSteelController extends BaseRESTfulController {

    @Autowired
    RmsMaterialSteelServiceImpl rmsMaterialSteelService;

    /**
     * 得到没有质保书的炉号
     *
     * @return
     */
    @ApiModelProperty(value = "得到没有质保书的炉号")
    @PostMapping("/getMaterialFurnaceNumber")
    public RESTfulResult getMaterialFurnaceNumber() {
        Map<String,Object> mapValue = rmsMaterialSteelService.getMaterialFurnaceNumber();
        return success(mapValue);
    }


    @PostMapping("/upload")
    public Map<String, Object> fileupload(MultipartFile file, HttpServletRequest req) {
        SimpleDateFormat sdf = new SimpleDateFormat("/yyyy/MM/dd/");
        //首先要给文件找一个目录
        //先写返回值
        Map<String, Object> result = new HashMap<>();
        //再用pdf格式开始书写,先找原始的名字
        String originName = file.getOriginalFilename();
        //判断文件类型是不是pdf
        if(!originName.endsWith(".pdf")){
            //如果不是的话，就返回类型
            result.put("status","error");
            result.put("msg","文件类型不对");
            return result;
        }
        //如果是正确的话，就需要写保存文件的文件夹
        //.format(new Date())的意思是 也就是格式化一个新的时间
        //Date会创建一个时间，然后会按照当前的sdf格式调用format将当前时间创建出来 直接调用new Date()可能会出现这种格式
        //Sun Feb 28 10:55:06 CST 2021
        //再是getServletContext
        String format=sdf.format(new Date());
        //这也是一个临时的路径，项目重启之后，他就会变的
        String realPath = req.getServletContext().getRealPath("/") +format;
        //再是保存文件的文件夹
        File folder = new File(realPath);
        //如果不存在，就自己创建
        if(!folder.exists()){
            folder.mkdirs();
        }
        String newName = UUID.randomUUID().toString() + ".pdf";
        //然后就可以保存了
        try {
            file.transferTo(new File(folder,newName));
            //这个还有一个url
            String url= req.getScheme()+"://"+req.getServerName()+":"+req.getServerPort()+format+newName;
            //如果指向成功了
            result.put("status","success");
            result.put("url",url);
            // 得到炉号
            int index = originName.indexOf(".");
            String materialFurnaceNumber = originName.substring(0, index);
            Map<String,Object> map = new HashMap<>();
            map.put("materialFurnaceNumber",materialFurnaceNumber);
            map.put("conclusionUrl",realPath);
            // 修改钢材质检结果
            Integer code = rmsMaterialSteelService.updateMaterialQuality(map);
        } catch (IOException e) {
            //返回异常
            result.put("status","error");
            result.put("msg",e.getMessage());
        }
        return  result;
    }

}
